import pytest
import unittest

from my_tool_package.connections import MyFirstConnection
from my_tool_package.tools.my_tool_1 import my_tool


@pytest.fixture
def my_custom_connection() -> MyFirstConnection:
    my_custom_connection = MyFirstConnection(api_key="my_api_key")
    return my_custom_connection


class TestMyTool1:
    def test_my_tool_1(self, my_custom_connection):
        result = my_tool(my_custom_connection, input_text="Hello Microsoft! ")
        assert result == "Hello Microsoft! This is my first connection."


# Run the unit tests
if __name__ == "__main__":
    unittest.main()



from promptflow import ToolProvider, tool
from my_tool_package.connections import MySecondConnection


class MyTool(ToolProvider):
    """
    Doc reference :
    """

    def __init__(self, connection: MySecondConnection):
        super().__init__()
        self.connection = connection

    @tool
    def my_tool(self, input_text: str) -> str:
        # Replace with your tool code.
        # Usually connection contains configs to connect to an API.
        # Not all tools need a connection. You can remove it if you don't need it.
        return input_text + self.connection.api_hint



import pytest
import unittest

from my_tool_package.connections import MySecondConnection
from my_tool_package.tools.my_tool_2 import MyTool


@pytest.fixture
def my_custom_connection() -> MySecondConnection:
    my_custom_connection = MySecondConnection(api_key="my_api_key")
    return my_custom_connection


@pytest.fixture
def my_tool_provider(my_custom_connection) -> MyTool:
    my_tool_provider = MyTool(my_custom_connection)
    return my_tool_provider


class TestMyTool2:
    def test_my_tool_2(self, my_tool_provider: MyTool):
        result = my_tool_provider.my_tool(input_text="Hello Microsoft! ")
        assert result == "Hello Microsoft! This is my second connection."


# Run the unit tests
if __name__ == "__main__":
    unittest.main()



from promptflow import tool
from my_tool_package.connections import MyFirstConnection


@tool
def my_tool(connection: MyFirstConnection, input_text: str) -> str:
    # Replace with your tool code.
    # Usually connection contains configs to connect to an API.
    # Not all tools need a connection. You can remove it if you don't need it.
    return input_text + connection.api_hint



from dataclasses import dataclass
from promptflow.contracts.types import Secret
from promptflow._core.tools_manager import register_connections


@dataclass
class MyFirstConnection():
    api_key: Secret
    api_hint: str = "This is my first connection."


@dataclass
class MySecondConnection():
    api_key: Secret
    api_hint: str = "This is my second connection."


register_connections([MyFirstConnection, MySecondConnection])
